@@ -1,11 +1,13 @@
 ;;; popwin.el --- Popup Window Manager
 
 ;; Copyright (C) 2011-2015  Tomohiro Matsuyama
+;; Copyright (C) 2020-2024  Jen-Chieh Shen
 
 ;; Author: Tomohiro Matsuyama <m2ym.pub@gmail.com>
+;; Maintainer: Jen-Chieh Shen <jcs090218@gmail.com>
 ;; Keywords: convenience
-;; Package-Version: 1.0.2
-;; Package-Revision: 215d6cb509b1
+;; Package-Version: 20240925.752
+;; Package-Revision: 58adcd0ca7c3
 ;; URL: https://github.com/emacsorphanage/popwin
 ;; Package-Requires: ((emacs "24.3"))
 
@@ -202,8 +204,9 @@ HFACTOR, and vertical factor VFACTOR."
     (cl-destructuring-bind (dir edges . windows) node
       (append (list dir edges)
               (cl-loop for window in windows
-                       unless (and (windowp window)
-                                   (window-parameter window 'window-side))
+                       unless (or (and (windowp window)
+                                       (window-parameter window 'window-side))
+                                  (not (windowp window)))
                        collect (popwin:window-config-tree-1 window))))))
 
 (defun popwin:window-config-tree ()
